/*
 * $Id$
 * Copyright (C) 2001 The Apache Software Foundation. All rights reserved.
 * For details on use and redistribution please refer to the
 * LICENSE file included with these sources.
 */

package org.apache.fop.fonts;

//import org.apache.fop.apps.FOPException;
//import org.apache.fop.layout.FontMetric;
//import org.apache.fop.layout.FontDescriptor;
//import org.apache.fop.render.pdf.CodePointMapping;
//import org.apache.fop.messaging.MessageHandler;

/**
 * Encapsulates information for fonts of interest to FOP,
 * regardless of their source.
 * Within FOP, a Font is a specific instance of the more general TypeFace,
 * which is itself a member of a TypeFaceFamily.
 * A Font is a TypeFace rendered at a specific size, and perhaps with
 * various transformations applied. The XSL-FO 1.0 standard does not support
 * any transformations, but they are possible in the future.
 * (The "font-stretch" property is actually a Typeface selection property,
 * not a transformation on a Font.)
 * Please note that the terms "font" and "typeface" are used interchangeably in
 * many other contexts. Scaleable font files, for example, usually contain
 * typeface data, or data for an entire family of typefaces.
 *
 * @author {@link <a href="mailto:vic@outfitr.com">Victor Mote</a>}
 * refactored existing code into this class.
 */
public class Font {

    /** The Typeface from which this font was derived. */
    private Typeface typeface;

    /** The Font size in points. */
    private int size;

    /**
     * This is the main constructor.
     */
    public Font(String family, String foStyle, String foWeight,
            int variant, int size) {
    }

    /** Returns the Typeface object for this font. */
    public Typeface getTypeface(){
        return typeface;
    }

    /** Returns the font size for this font (in points). */
    public int getSize(){
        return size;
    }

    /** Returns the width of a given character number.
     * This value does not consider letter spacing.
     * The original doc indicated that the value returned was in millipoints.
     * However, the division by 1000 would lead one to believe that the value
     * returned is points.
     */
    public int charWidth(int charnum) {
        return (typeface.getFontMetric().width(charnum, size) / 1000);
    }

    /** Overloaded to allow passage of letterSpacing. */
    public int charWidth(int charnum, int letterSpacing) {
        return (letterSpacing + charWidth(charnum));
    }

    public int getAscender() {
        return typeface.getFontMetric().getAscender(size) / 1000;
    }

    public int getDescender() {
        return typeface.getFontMetric().getDescender(size) / 1000;
    }

}

/* Last Line of $RCSfile$ */
