/*
 * $Id$
 * Copyright (C) 2001 The Apache Software Foundation. All rights reserved.
 * For details on use and redistribution please refer to the
 * LICENSE file included with these sources.
 */

package org.apache.fop.fonts;

import org.apache.fop.fonts.Typeface;
import java.util.HashMap;

/**
 * This class contains information about typeface families registered to and/or
 * used within FOP.
 *
 * To Do:
 * <ul>
 *   <li> Consider adding fields to this class that keep track of which
 *     typefaces in this family have certain characteristics (bold, italic,
 *     small caps, etc., or provide methods that iterate through the
 *     Typeface objects looking for such information.
 *   </li>
 *   <li> Consider adding a Collection of daughter Typefaces, or a method
 *     to iterate through Typeface objects looking for them.
 * </ul>
 *
 * @see org.apache.fop.fonts.Typeface
 * @see org.apache.fop.fonts.Font
 *
 * @author {@link <a href="mailto:vic@outfitr.com">Victor Mote</a>}
 */
public class TypefaceFamily {

    private String name;

    /** Source (base14, direct access, indirect access). */
    private int source = 0;
    /** Source is base-14 (hard-coded). */
    public final static int SOURCE_HARD_CODED = 1;
    /** Source is indirect access (registered at operating system
    level, or created using java.awt.Font.createFont). */
    public final static int SOURCE_INDIRECT_ACCESS = 2;
    /** Source is from metric information configured by user */
    public final static int SOURCE_DIRECT_ACCESS = 3;

    /** @return the name of this TypefaceFamily. */
    public String getName(){
        return name;
    }

    /** @return The source of this TypefaceFamily. */
    public int getSource(){
        return source;
    }

    /**
     * Normalizes a TypefaceFamily name by handling quotation marks
     * and white space.
     */
    public static String normalizeTypefaceFamilyName(String inputFF){
        //Checks for quoted TypefaceFamily name
        if (inputFF.charAt(0) == '"' || inputFF.charAt(0) == '\''){
            return inputFF.substring(1, inputFF.length()-1);
        }
        else {
            //In a nonquoted TypefaceFamily name any sequence of whitespace
            //inside should be converted to a single space
            StringBuffer sb = new StringBuffer();
            boolean spaced = false;
            for (int i=0; i<inputFF.length(); i++) {
                char c = inputFF.charAt(i);
                if (!isTypefaceFamilyWhitespace(c)) {
                    sb.append(c);
                    spaced = false;
                }
                else if (!spaced) {
                    sb.append(c);
                    spaced = true;
                }
            }
            return sb.toString();
        }
    }

    private static boolean isTypefaceFamilyWhitespace(char ch) {
        return (ch <= 0x0020) &&
            (((((1L << 0x0009) |
            (1L << 0x000A) |
            (1L << 0x000C) |
            (1L << 0x000D) |
            (1L << 0x0020)) >> ch) & 1L) != 0);
    }

}

/* Last Line of $RCSfile$ */
